pub fn load_vanilla_structure_sets() -> Vec<(Identifier, StructureSet)>Expand description
Loads all vanilla structure sets from the generated registry data.
pub fn load_vanilla_structure_sets() -> Vec<(Identifier, StructureSet)>Loads all vanilla structure sets from the generated registry data.