pub struct StructurePlacement {
pub salt: i32,
pub frequency: f32,
pub frequency_reduction_method: FrequencyReductionMethod,
pub exclusion_zone: Option<ExclusionZone>,
pub locate_offset: IVec3,
pub kind: PlacementKind,
}Expand description
Structure placement configuration.
Fields
salt: i32Unique seed modifier.
frequency: f32Probability of generating on a placement-chunk. 1.0 = always.
frequency_reduction_method: FrequencyReductionMethodFrequency-reduction method.
exclusion_zone: Option<ExclusionZone>Optional exclusion zone against another structure set.
locate_offset: IVec3Block offset from the placement chunk used by /locate.
kind: PlacementKindKind-specific parameters.
Implementations
Sourceimpl StructurePlacement
impl StructurePlacement
Sourcepub const fn locate_pos(&self, chunk_pos: ChunkPos) -> BlockPos
pub const fn locate_pos(&self, chunk_pos: ChunkPos) -> BlockPos
Locate result block position for a valid placement chunk.
Sourcepub fn is_structure_chunk(
&self,
seed: i64,
source_x: i32,
source_z: i32,
ring_positions: Option<&[ChunkPos]>,
) -> bool
pub fn is_structure_chunk( &self, seed: i64, source_x: i32, source_z: i32, ring_positions: Option<&[ChunkPos]>, ) -> bool
Valid placement chunk + frequency check. For ConcentricRings,
ring_positions must be pre-computed.
fn is_placement_chunk( &self, seed: i64, source_x: i32, source_z: i32, ring_positions: Option<&[ChunkPos]>, ) -> bool
Sourcepub fn get_potential_structure_chunk(
seed: i64,
salt: i32,
source_x: i32,
source_z: i32,
spacing: i32,
separation: i32,
spread_type: SpreadType,
) -> ChunkPos
pub fn get_potential_structure_chunk( seed: i64, salt: i32, source_x: i32, source_z: i32, spacing: i32, separation: i32, spread_type: SpreadType, ) -> ChunkPos
Deterministic structure chunk for the grid cell containing (source_x, source_z).